psu-ng: Rename supportedConfIfaceAdded

Rename the supportConfIfaceAdded function to entityMangerIfaceAdded, as
it will be used to handle the SupporteConfiguration interface being
added, as well as the IBMCFFPSConnecor interface.

Signed-off-by: Brandon Wyman <bjwyman@gmail.com>
Change-Id: Ib2a1564b5467153d8a960a1b39b2df4afa1147f8
diff --git a/phosphor-power-supply/psu_manager.hpp b/phosphor-power-supply/psu_manager.hpp
index d3d101a..f651a28 100644
--- a/phosphor-power-supply/psu_manager.hpp
+++ b/phosphor-power-supply/psu_manager.hpp
@@ -181,13 +181,14 @@
     void powerStateChanged(sdbusplus::message::message& msg);
 
     /**
      * @brief Callback for supported configuration interface added
      *
-     * Process the information from the supported configuration interface
+     * Process the information from the supported configuration and or IBM CFFPS
+     * Connector interface being added.
      *
      * @param[in] msg - Data associated with the interfaces added signal
      */
-    void supportedConfIfaceAdded(sdbusplus::message::message& msg);
+    void entityManagerIfaceAdded(sdbusplus::message::message& msg);
 
     /**
      * @brief Adds properties to the inventory.
@@ -181,13 +181,14 @@
 
     /**
-     * @brief Callback for supported configuration interface added
+     * @brief Callback for entity-manager interface added
      *